
 - Make acpi_pci_irq_lookup() static since nothing outside pci_irq.c uses it.
 - Change its arguments to take a struct pci_bus * rather than segment, busnr.
 - Use pci_domain_nr() to get the segment number instead of assuming 0.

Index: drivers/acpi/acpi_ksyms.c
===================================================================
RCS file: /var/cvs/linux-2.5/drivers/acpi/acpi_ksyms.c,v
retrieving revision 1.12
diff -u -p -r1.12 acpi_ksyms.c
--- drivers/acpi/acpi_ksyms.c	27 May 2003 17:22:25 -0000	1.12
+++ drivers/acpi/acpi_ksyms.c	11 Jun 2003 12:26:40 -0000
@@ -144,8 +144,6 @@ EXPORT_SYMBOL(acpi_bus_unregister_driver
 #include <linux/pci.h>
 extern int acpi_pci_irq_enable(struct pci_dev *dev);
 EXPORT_SYMBOL(acpi_pci_irq_enable);
-extern int acpi_pci_irq_lookup (int segment, int bus, int device, int pin);
-EXPORT_SYMBOL(acpi_pci_irq_lookup);
 #endif /*CONFIG_ACPI_PCI */
 
 #ifdef CONFIG_ACPI_EC
Index: drivers/acpi/pci_irq.c
===================================================================
RCS file: /var/cvs/linux-2.5/drivers/acpi/pci_irq.c,v
retrieving revision 1.10
diff -u -p -r1.10 pci_irq.c
--- drivers/acpi/pci_irq.c	25 Feb 2003 12:39:42 -0000	1.10
+++ drivers/acpi/pci_irq.c	11 Jun 2003 12:27:05 -0000
@@ -229,22 +229,20 @@ acpi_pci_irq_add_prt (
                           PCI Interrupt Routing Support
    -------------------------------------------------------------------------- */
 
-int
-acpi_pci_irq_lookup (
-	int			segment,
-	int			bus,
-	int			device,
-	int			pin)
+static int
+acpi_pci_irq_lookup (struct pci_bus *bus, int device, int pin)
 {
 	struct acpi_prt_entry	*entry = NULL;
+	int segment = pci_domain_nr(bus);
+	int bus_nr = bus->number;
 
 	ACPI_FUNCTION_TRACE("acpi_pci_irq_lookup");
 
 	ACPI_DEBUG_PRINT((ACPI_DB_INFO, 
 		"Searching for PRT entry for %02x:%02x:%02x[%c]\n", 
-		segment, bus, device, ('A' + pin)));
+		segment, bus_nr, device, ('A' + pin)));
 
-	entry = acpi_pci_irq_find_prt_entry(segment, bus, device, pin); 
+	entry = acpi_pci_irq_find_prt_entry(segment, bus_nr, device, pin); 
 	if (!entry) {
 		ACPI_DEBUG_PRINT((ACPI_DB_INFO, "PRT entry not found\n"));
 		return_VALUE(0);
@@ -288,7 +286,8 @@ acpi_pci_irq_derive (
 	while (!irq && bridge->bus->self) {
 		pin = (pin + PCI_SLOT(bridge->devfn)) % 4;
 		bridge = bridge->bus->self;
-		irq = acpi_pci_irq_lookup(0, bridge->bus->number, PCI_SLOT(bridge->devfn), pin);
+		irq = acpi_pci_irq_lookup(bridge->bus,
+				PCI_SLOT(bridge->devfn), pin);
 	}
 
 	if (!irq) {
@@ -331,7 +330,7 @@ acpi_pci_irq_enable (
 	 * First we check the PCI IRQ routing table (PRT) for an IRQ.  PRT
 	 * values override any BIOS-assigned IRQs set during boot.
 	 */
- 	irq = acpi_pci_irq_lookup(0, dev->bus->number, PCI_SLOT(dev->devfn), pin);
+ 	irq = acpi_pci_irq_lookup(dev->bus, PCI_SLOT(dev->devfn), pin);
  
 	/*
 	 * If no PRT entry was found, we'll try to derive an IRQ from the
